# Services events

## Generated by Photometer service

'phot_info'.           info: role and photometer info (device name, mac, etc).
'phot_sample'          info: role and sample
'phot_firmware'.       info: role and firmware string. Generated when conflictive firmware is detected
'phot_offline'.        info: role. Generated when not detected

## Generated by Statistics service
'stats_info'.          info: role and statistics dict fro a give time
'stats_progress'       Info: role and buffer info dict when no statistcs are computed yet.

## Generated by Calibration service
'calib_begin'.         info: session
'calib_end'            info: none
'calib_summary_info'.  info: role and summary dict.
'calib_round_info'.    Info role and same statistics dict as 'stats_info' plus calculated ZP, round # and magnitude differential.
'calib_flash_zp'       Info: new zp to flash.
'calib_summary_lists'  >Info: lists of best ZPs, Ref Freqs and Test Freqs

# GUI events

## Other
'quit'. Info: exit_code. Generated by Application and everywhere when no exception is handled to quit application.
'bootstrap_req'. No info. generated by GUI Service

## Generated by Menu bar
'database_version_req'. No info. 


## Generated by Status bar
'status_bar_req'. No info.

## Generated by Preferences Dialog
'gui_preferences_close'. No info. generated by preferences dialog
'test_config_load_req'. Info: None
'ref_config_load_req'. Info None
'test_config_save_req'. Info: config dict for sections test-stats and test-device
'ref_config_save_req'. Info: config dict for sections ref-stats and ref-device

## Generated by the Main Panel
'start_photometer_req'. Info: role. 
'stop_photometer_req'. Info: role.
'start_calibration_req' Info: None
'stop_calibration_req'. Info. None
'save_calib_config_req. Info: config dict for calibration section


